begin_mode

Function begin_mode 

pub fn begin_mode(mode: &str) -> Result<()>
Begin processing in mode; one of “text”, “display-math” or “inline-math”. This also begins a new level of grouping and switches to a font appropriate for the mode. If noframe is true, skip pushing a stack frame (e.g. for \begin{document}). Perl: sub beginMode (Stomach.pm lines 474-517)