digest

Function digest 

pub fn digest<T: Into<Tokens>>(tokens: T) -> Result<Digested>
Digest a list of tokens independent from any current Gullet. Typically used to digest arguments to primitives or constructors. Returns a List containing the digested material.