get_script_level

Function get_script_level 

pub fn get_script_level() -> usize
ScriptLevel is similar to boxing level, but relative to current Math mode’s level

This is used for the scriptpos attribute to recognize overlapping sccripts. Making it relative to the math’s level avoids unnecessary changes