pub struct Stomach {
pub token_stack: Vec<Token>,
pub boxing: Vec<Token>,
pub box_list: Vec<Digested>,
/* private fields */
}Expand description
The Stomach is responsible for digesting tokens into boxes, lists, etc.
Fields
token_stack: Vec<Token>currently invoked tokens
boxing: Vec<Token>tracks the tokens of boxing groups(?)
box_list: Vec<Digested>collects the intermediate boxes resulting from a digest call.