pub fn invoke_token(input_token: &Token) -> Result<Vec<Digested>>Expand description
Invoke a token
If it is a primitive or constructor, the definition will be invoked, possibly arguments will be parsed from the Gullet. Otherwise, the token is simply digested: turned into an appropriate box. Returns a list of boxes/whatsits.