pub fn raw_tex(text: &str) -> Result<()>
a convenience function for including chunks of raw TeX (or LaTeX) code It is useful for copying portions of the normal implementation that can be handled simply using macros and primitives.